@@ -107,7 +107,7 @@ vedo_example_db =
         imgsrc: 'images/basic/silhouette2.png',
     },
     {
-        pyname: 'cutter',
+        pyname: 'cut_interactive',
         kbd   : '',
         categ : 'basic',
         short : 'interactive mesh cutter',
@@ -767,7 +767,7 @@ vedo_example_db =
         imgsrc: 'images/advanced/timer_callback1.jpg',
     },
     {
-        pyname: 'spline_draw',
+        pyname: 'spline_draw1',
         kbd   : '',
         categ : 'advanced',
         short : 'draw a spline',
@@ -1453,7 +1453,7 @@ vedo_example_db =
         imgsrc: 'images/pyplot/fit_erf.png',
     },
     {
-        pyname: 'fit_curve',
+        pyname: 'fit_curve1',
         kbd   : '',
         categ : 'plotting',
         short : 'fit data w/ error bars',
