@@ -6,6 +6,6 @@ settings.use_depth_peeling = True
 
 spid = Mesh(dataurl+"spider.ply").c("brown")
 
-ch = ConvexHull(spid.vertices).alpha(0.2)
+ch = ConvexHull(spid).alpha(0.2)
 
 show(spid, ch, __doc__, axes=1).close()
