@@ -1,34 +1,27 @@
-"""Usage example of fitLine() and fitPlane()
-
-Draw a line in 3D that fits a cloud of 20 Points,
-Show the first set of 20 points and fit a plane to them"""
-import numpy as np
+"""Draw a line in 3D that fits a cloud of 20 Points,
+Show the first set of 20 points and fit a plane to them."""
 from vedo import *
 
-settings.use_depth_peeling = True
-
 # declare the class instance
-plt = Plotter()
+plt = Plotter(axes=1)
 
 # draw 500 fit lines superimposed and very transparent
 for i in range(500):
-
     x = np.linspace(-2, 5, 20)  # generate every time 20 points
     y = np.linspace(1, 9, 20)
     z = np.linspace(-5, 3, 20)
     data = np.stack((x,y,z), axis=1)
-    data += np.random.normal(size=data.shape) * 0.8  # add gauss noise
-
+    data+= np.random.normal(size=data.shape) * 0.8  # add gauss noise
     plt += fit_line(data).lw(4).alpha(0.04).c("violet")  # fit a line
 
 # 'data' still contains the last iteration points
-plt += Points(data, r=10, c="yellow")
+plt += Points(data).color("yellow").ps(10)
 
-print("Line 0 Fit slope = ", plt.actors[0].slope)
+print("Line 0 Fit slope = ", plt.objects[0].slope)
 
 plane = fit_plane(data).c("green4")  # fit a plane
 print("Plane Fit normal =", plane.normal)
 
-plt += [plane, __doc__]
+plt += plane, __doc__
 
-plt.show(axes=1).close()
+plt.show().close()
