@@ -3,7 +3,7 @@ from vedo import Grid, show
 
 # Make up some quad mesh with associated scalars
 g1 = Grid(res=(25,25)).wireframe(0).lw(1)
-scalars = g1.vertices[:,1]
+scalars = g1.coordinates[:,1]
 g1.cmap("viridis", scalars, vmin=-1, vmax=1, name='gene')
 g1.map_points_to_cells()  # move the array to cells (faces)
 g1.add_scalarbar(horizontal=1, pos=(0.7,0.04))
