@@ -9,7 +9,7 @@ plt1 = Plotter(N=3, axes=1)
 
 mesh = Mesh(dataurl+"bunny.obj").normalize().subdivide()
 
-pts = mesh.vertices
+pts = mesh.coordinates
 pts += np.random.randn(len(pts), 3)/20  # add noise, will not mess up the original points
 
 
@@ -36,8 +36,8 @@ vmin, vmax = np.min(variances), np.max(variances)
 print("min and max of variances:", vmin, vmax)
 vcols = [color_map(v, "jet", vmin, vmax) for v in variances]  # scalars->colors
 
-sp0 = Spheres(mls2.vertices, c=vcols, r=0.02)         # error as color
-sp1 = Spheres(mls2.vertices, c="red5", r=variances/4) # error as point size
+sp0 = Spheres(mls2.coordinates, c=vcols, r=0.02)         # error as color
+sp1 = Spheres(mls2.coordinates, c="red5", r=variances/4) # error as point size
 
 mesh.color("k").alpha(0.05).wireframe()
 
