@@ -11,7 +11,7 @@ meshdec = mesh.clone().triangulate().decimate(n=200)
 
 sources = [[0.9, 0.0, 0.2]]  # this point moves
 targets = [[1.2, 0.0, 0.4]]  # ...to this.
-for pt in meshdec.points():
+for pt in meshdec.vertices:
     if pt[0] < 0.3:          # these pts don't move
         sources.append(pt)   # (e.i. source = target)
         targets.append(pt)
