@@ -13,9 +13,9 @@ pts2 = [(u(0, x) + 3, u(0, x) + i / 2 + 2, u(0, x) + i + 1) for i in range(N)]
 pts3 = [(u(0, x) + 4, u(0, x) + i / 4 - 3, u(0, x) + i - 2) for i in range(N)]
 
 # Convert the sets of points into Points objects with different colors and sizes
-vpts1 = Points(pts1, c="r", r=8)
-vpts2 = Points(pts2, c="g", r=8)
-vpts3 = Points(pts3, c="b", r=8)
+vpts1 = Points(pts1).c("r").ps(8)
+vpts2 = Points(pts2).c("g").ps(8)
+vpts3 = Points(pts3).c("b").ps(8)
 
 # Perform Procrustes alignment on the sets of points
 #  and obtain the aligned sets
