@@ -8,19 +8,23 @@ from vedo import *
 # settings.enable_default_keyboard_callbacks = False
 # settings.enable_default_mouse_callbacks = False
 
-msh = Mesh(dataurl+'mouse_brain.stl').backcolor("purple8")
+msh = Mesh(dataurl+'mouse_brain.stl').subdivide()
+msh.backcolor("purple8").print()
 
+# Create the plotter with the mesh, do not block the execution
 plt = Plotter(bg='blackboard', interactive=False)
 plt.show(msh, __doc__, viewup='z')
 
+# Create the cutter object
 cutter = PlaneCutter(msh)
 # cutter = BoxCutter(msh)
 # cutter = SphereCutter(msh)
 
-plt.add(cutter)
-plt.interactive()
+# Add the cutter to the renderer and show
+plt.add(cutter).interactive()
 
-plt.remove(cutter)
-plt.interactive()
+# Remove the cutter from the renderer and show
+plt.remove(cutter).interactive()
 
+# close the plotter
 plt.close()
