@@ -1,11 +1,13 @@
-from vedo import *
+from vedo import dataurl, Mesh, Plotter
 
 styles = ['default', 'metallic', 'plastic', 'shiny', 'glossy', 'ambient', 'off']
 
 msh = Mesh(dataurl+"beethoven.ply").c('gold').subdivide()
 
+plt = Plotter(N=len(styles), bg='bb')
+
 for i,s in enumerate(styles):
     msh_copy = msh.clone(deep=False).lighting(s)
-    show(msh_copy, s, at=i, N=len(styles), bg='bb')
+    plt.at(i).show(msh_copy, s)
 
-interactive().close()
+plt.interactive().close()
