@@ -2,10 +2,10 @@
 from vedo import dataurl, Mesh, Sphere, show
 
 spider = Mesh(dataurl+"spider.ply")
-spider.normalize().rotate_z(-90)
+# spider.rotate_z(-90).normalize()
 spider.texture(dataurl+'textures/leather.jpg')
 spider.add_shadow('x', -3)
 
-sphere = Sphere(r=0.3).pos(0.4,0,0.6).add_shadow('x', -3)
+sphere = Sphere(r=0.4).pos(0.5,0,1).add_shadow('x', -3)
 
 show(spider, sphere, __doc__, axes=1, viewup="z").close()
