@@ -8,7 +8,7 @@ from vedo import *
 settings.default_font = "Kanopus"
 
 s = Hyperboloid().rotate_x(20)
-pts = s.vertices
+pts = s.points
 n = len(pts)
 
 plt = Plotter(title="Example of project_on_plane()")
@@ -18,7 +18,7 @@ plt += [s, __doc__ + settings.default_font]
 plane1 = Plane(pos=(2, 0, 2), normal=(1, 0, 1), s=[5, 5]).alpha(0.1)
 so = s.clone().project_on_plane(plane1).c("y")
 plt += [plane1, so, so.silhouette("2d")]
-pts1 = so.silhouette("2d").vertices
+pts1 = so.silhouette("2d").points
 
 # perspective projection ##############################
 plane2 = Plane(pos=(3, 3, 3), normal=(1, 1, 1), s=[5, 5]).alpha(0.1)
@@ -30,7 +30,7 @@ plt += [plane2, sp, sp.silhouette("2d")]
 plane3 = Plane(pos=(4, 8, -4), normal=(-1, 0, 1), s=[5, 5]).alpha(0.1)
 sob = s.clone().project_on_plane(plane3, direction=(1, 2, -1)).c("g")
 plt += [plane3, sob, sob.silhouette("2d")]
-pts2 = sob.silhouette("2d").vertices
+pts2 = sob.silhouette("2d").points
 
 # draw the lines
 for i in range(0, n, int(n / 20)):
