@@ -10,7 +10,7 @@ def slider2(widget, event):
     mesh.alpha(widget.value)
 
 
-mesh = Mesh(dataurl+"magnolia.vtk").flat().lw(0.1)
+mesh = Mesh(dataurl+"magnolia.vtk").flat().lw(1)
 
 plt = Plotter()
 plt += [mesh, __doc__]
