@@ -1,4 +1,4 @@
-"""Create a range slider to scale two spheres"""
+"""Create a double range slider to scale two spheres"""
 from vedo import *
 
 
