@@ -1,9 +1,8 @@
 """Use array to vary radius and color
 of a line represented as a tube"""
 from vedo import *
-import numpy as np
 
-settings.defaultFont = 'Quikhand'
+settings.default_font = 'Quikhand'
 
 ln = [[sin(x), cos(x), x / 2] for x in np.arange(0,9, 0.1)]
 N = len(ln)
@@ -17,11 +16,11 @@ t2 = Tube(ln, r=rads, c="tomato", res=24)
 
 ############################### vary color
 cols = list(range(N))
-cols = makeBands(cols, 5)  # make color bins
+cols = make_bands(cols, 5)  # make color bins
 t3 = Tube(ln, r=rads, c=cols, res=24)
 
 ############################### visualize
-plt = Plotter(N=3, axes=dict(textScale=4))
+plt = Plotter(N=3, axes=dict(text_scale=4))
 plt.at(0).show(t1, __doc__)
 plt.at(1).show(t2)
 plt.at(2).show(t3, viewup="z")
