@@ -9,16 +9,19 @@ from trame.widgets import vtk, vuetify
 
 import vedo
 
-cone = vedo.Cone()
+sphere = vedo.Sphere().lw(1)
+sphere.cmap("Spectral_r", sphere.vertices[:, 1])
+axes = vedo.Axes(sphere)
 
 plt = vedo.Plotter()
-plt += cone
+plt += sphere
+plt += axes.unpack()
+plt += vedo.Text3D("A color sphere", font='Quikhand', s=0.2, pos=[-1,1,-1])
 
 # -----------------------------------------------------------------------------
 # Trame
 # -----------------------------------------------------------------------------
 server = get_server()
-
 with SinglePageLayout(server) as layout:
     layout.title.set_text("Hello trame")
 
