@@ -9,10 +9,9 @@ axs = Axes(
     [vpts1, vpts2],  # build axes for this set of objects
     xtitle="X-axis in :mum",
     ytitle="Variable Y in :mum",
-    ztitle="_inverted Z in :mum",
+    ztitle="Inverted Z in :mum",
     htitle='My :Gamma^2_ijk  plot',
     htitle_font='Kanopus',
-    htitle_justify='bottom-right',
     htitle_color='red2',
     htitle_size=0.035,
     htitle_offset=(0,0.075,0),
