@@ -19,9 +19,10 @@ axes3 = Axes(s3, c='b', number_of_divisions=10)
 # axes3 is an Assembly (group of Meshes).
 # Unpack it and scale the 7th label getting it by its name,
 # make it 5 times bigger big and fuchsia:
-axes3.unpack('xNumericLabel7').scale(5).c('fuchsia')
+
 # Print all element names in axes3:
 #for m in axes3.get_meshes(): print(m.name)
+axes3['xNumericLabel 7'].scale(5).c('fuchsia')
 
 # By specifiyng axes in show(), new axes are
 #  created which span the whole bounding box.
