@@ -9,7 +9,7 @@ acts = [
     violin(np.random.randn(n)),
 
     Text3D('exponential', pos=(5,-1), s=0.3, c='k', justify='center'),
-    violin(np.random.exponential(1, n), x=5, width=3, spline=False, centerline=False, c='t', lc='k'),
+    violin(np.random.exponential(1, n), x=5, width=3, splined=False, centerline=False, c='t', lc='k'),
 
     Text3D('chisquare', pos=(10,11), s=0.3, c='k', justify='center'),
     violin(np.random.chisquare(9, n)/4, x=10, vlim=(0,10), c='lg', lc='dg'),
