@@ -7,7 +7,7 @@ plt = Plotter(size=(1500,300))
 plt += __doc__
 
 for i,s in enumerate(symbols):
-    plt += Marker(s, filled=True).x(i*0.6).backColor('blue5')
+    plt += Marker(s, filled=True).x(i*0.6).backcolor('blue5')
     plt += Text3D(s, pos=[i*0.6,-0.6,0], s=0.12, literal=True, font="Calco")
 
 plt.show(zoom='tight').close()
