@@ -13,12 +13,12 @@ fig = plot(
     x, y,
     "*r-",           # markers: *,o,p,h,D,d,v,^,s,x,a
 	title=__doc__,
-    xtitle="t variable (\mus)",
-    ytitle="y(x) = \pmK_i \dot\sqrtsin^2 t",
+    xtitle="t variable (:mus)",
+    ytitle="y(x) = :pmK_i :dot:sqrtsin^2 t",
     aspect=16/9,     # aspect ratio x/y of plot
     xlim=(-1, 14),   # specify x range
     axes=dict(text_scale=1.2),
-    label="3 \dot sin(x)",
+    label="3 :dot sin(x)",
 )
 
 ################# plot on top of fig
@@ -28,14 +28,14 @@ fig += plot(
     like=fig,        # format like fig
     splined=True,    # continuous spline through points
     lw=3,            # line width
-    label="3 \dot sin(x - \pi)",
+    label="3 :dot sin(x - :pi)",
 )
 
 ################## plot again on top of fig
-fig += plot(x, y/5, "g", label="3/5 \dot sin(x)")
+fig += plot(x, y/5, "g", label="3/5 :dot sin(x)")
 
 ################## plot again on top of fig
-fig += plot(x, y/5-1, "purple5 -", label="3/5 \dot sin(x) - 1")
+fig += plot(x, y/5-1, "purple5 -", label="3/5 :dot sin(x) - 1")
 
 ################## Show! ##################
 fig.add_legend(pos=[0.95,1])
