@@ -2,7 +2,7 @@
 from vedo import np, settings, show
 from vedo.pyplot import plot
 
-settings.defaultFont = 'Theemim'
+settings.default_font = 'Theemim'
 
 def f(x):
     return 3*np.exp(-x)*np.cos(2*x)**2
@@ -22,16 +22,16 @@ fig2 = plot(
     xb, f(xb),
     title='3 e^-x cos 2x**2  (wider range)',
     xtitle=' ', ytitle=' ',  # leave empty
-    lc='red5',
+    c='red5',
     axes=dict(
-        xyPlaneColor='#dae3f0',
-        gridLineWidth=0, # make it solid
-        xyAlpha=1,       # make it opaque
-        textScale=2,     # make text bigger
+        xyplane_color='#dae3f0',
+        grid_linewidth=0, # make it solid
+        xyalpha=1,        # make it opaque
+        text_scale=2,     # make text bigger
     )
 )
 # Scale fig to make it smaller
-fig2.scale(0.04).shift(0.05, 0.75, 0.1)
+fig2.scale(0.04).shift(0.05, 0.75)
 
 fig1.insert(fig2)  ############# insert
 
