@@ -3,8 +3,8 @@ from vedo import Grid, Arrows2D, show
 
 
 # Create displacements
-pts1 = Grid(s=[1.0,1.0]).vertices
-pts2 = Grid(s=[1.2,1.2]).rotate_z(4).vertices
+pts1 = Grid(s=[1.0,1.0]).points
+pts2 = Grid(s=[1.2,1.2]).rotate_z(4).points
 
 quiv = Arrows2D(pts1, pts2).c("red5")
 
