@@ -30,7 +30,7 @@ axes = Axes(xrange=[-1,9],
             yrange=[-3,5],
             htitle=':beta_c  expression: change in time',
             xtitle=' ',
-            ytitle='Level of :beta_c  protein in \muM/l',
+            ytitle='Level of :beta_c  protein in :muM/l',
             x_values_and_labels=[(0,'Experiment^A\n at t=1h'),
                                  (4,'Experiment^B\n at t=2h'),
                                  (8,'Experiment^C\n at t=4h'),
