@@ -7,13 +7,13 @@ l =  3  # length of one segment
 def func(evt):
     if not evt.object:
         return
-    coords = line.vertices
+    coords = line.points
     coords[0] = evt.picked3d
     for i in range(1, n):
         v = versor(coords[i] - coords[i-1])
         coords[i] = coords[i-1] + v * l
-    line.vertices = coords  # update positions
-    nodes.vertices = coords
+    line.points = coords  # update positions
+    nodes.points = coords
     plt.render()
 
 surf = Plane(s=[60, 60])
