@@ -34,8 +34,8 @@ for b1, b2 in zip(p1,p2):
     ball2.pos(b2)
     ball1.update_trail().update_shadows()
     ball2.update_trail().update_shadows()
-    rod1.vertices = [[0,0,0], b1]
-    rod2.vertices = [b1, b2]
+    rod1.points = [[0,0,0], b1]
+    rod2.points = [b1, b2]
     rod1.update_shadows()
     rod2.update_shadows()
     plt.render()
