@@ -11,12 +11,12 @@ pin = s.inside_points(pts)
 pin.subsample(0.05)  # impose min separation (5% of bounding box)
 printc("# of points inside the sphere:", pin.npoints)
 
-tmesh = delaunay3d(pin).shrink(0.95)
+tmesh = pin.generate_delaunay3d().shrink(0.95)
 
 cmesh = tmesh.cut_with_plane(normal=(1,2,-1))
 # cmesh.pipeline.show()  # to show the graph of operations
 
 show([(s, pin, "Generate points in a Sphere"),
-      (cmesh, __doc__),
+      (cmesh.tomesh(), __doc__),
      ], N=2, axes=1,
 ).close()
