@@ -17,7 +17,7 @@ pts.pointdata["scals"] = scals
 # available interpolation kernels are: shepard, gaussian, voronoi, linear.
 vol = pts.tovolume(kernel='shepard', n=4, dims=(90,90,90))
 
-vol.c(["maroon","g","b"])        # set color   transfer function
+vol.cmap(["maroon","g","b"])     # set color   transfer function
 vol.alpha([0.3, 0.9])            # set opacity transfer function
 #vol.alpha([(0.3,0.3), (0.9,0.9)]) # alternative way, by specifying (xscalar, alpha)
 vol.alpha_unit(0.5)              # make the whole object less transparent (default is 1)
@@ -29,6 +29,6 @@ vol.threshold(above=0.3, below=0.4, replace=0.9)
 ch = CornerHistogram(vol, pos="bottom-left")
 
 vol.add_scalarbar3d('Height is the voxel scalar', size=[None,1])
-vol.scalarbar.rotate_x(90).pos(1.15,1,0.5)
+vol.scalarbar.rotate_x(90).pos(0,1,0)
 
 show(pts, vol, ch, __doc__, axes=1, elevation=-90).close()
