@@ -1,5 +1,4 @@
 """Load and render a 3D Volume
-
 mode=0, composite rendering
 mode=1, maximum-projection rendering"""
 from vedo import dataurl, Volume, show
@@ -18,13 +17,14 @@ vol1.alpha([0.0, 0.2, 0.3, 0.8])
 # a transparency for the GRADIENT of the scalar can also be set:
 # in this case when the scalar is ~constant the gradient is ~zero
 # and the voxel are made transparent:
-vol1.alpha_gradient([0.0, 0.5, 0.9]).add_scalarbar3d('composite shade', c='k')
-vol1.scalarbar.scale(0.8).x(20)
+vol1.alpha_gradient([0.0, 0.5, 0.9])
+vol1.add_scalarbar3d('composite shade')
+vol1.scalarbar = vol1.scalarbar.clone2d("center-right", size=0.2)
 
 # mode = 1 is maximum-projection volume rendering
-vol2 = Volume(dataurl+"vase.vti").mode(1).shift(60,0,0)
-vol2.add_scalarbar3d('maximum-projection', c='k')
-vol2.scalarbar.scale(0.8).x(160)
+vol2 = Volume(dataurl+"vase.vti").mode(1)
+vol2.add_scalarbar3d('maximum-projection')
+vol2.scalarbar = vol2.scalarbar.clone2d("center-right", size=0.2)
 
 # show command creates and returns an instance of class Plotter
-show(vol1, vol2, __doc__, size=(800,600), zoom=1.5).close()
+show([[vol1, __doc__], vol2], N=2, axes=1).close()
