@@ -8,7 +8,7 @@ def func(evt):
     pid = evt.object.closest_point(evt.picked3d, return_point_id=True)
     txt = f"Probing:\n{precision(evt.object.picked3d, 3)}\nvalue = {arr[pid]}"
 
-    pts = evt.object.vertices
+    pts = evt.object.points
     sph = Sphere(pts[pid]).c('orange7').pickable(False)
     fp = sph.flagpole(txt, s=7, offset=(-150,15), font=2).follow_camera()
     # remove old and add the two new objects
