@@ -6,9 +6,9 @@ volumes = load(volumes)
 cmaps = ['hot_r', 'gist_ncar_r', 'bone_r']
 
 ########################################################################
-def initfunc(iren, data):
+def initfunc(iren, vol):
 
-    vol = data.mode(1).c('k').alpha([0, 0, 0.15, 0, 0])
+    vol.mode(1).cmap('k').alpha([0, 0, 0.15, 0, 0])
     txt = Text2D(data.filename[-20:], font='Calco')
     plt.at(iren).show(vol, vol.box(), txt)
 
@@ -19,6 +19,7 @@ def initfunc(iren, data):
         msh.cmap(cmaps[iren]).lighting("off")
         msh.name = "slice"
         sb = ScalarBar3D(msh, c='k')
+        # sb = sb.clone2d("bottom-right", 0.08)
         plt.renderer = widget.renderer  # make it the current renderer
         plt.remove("slice", "ScalarBar3D").add(msh, sb)
 
