@@ -1,9 +1,10 @@
 from vedo import *
 
-ug = Mesh('https://github.com/marcomusy/vedo/files/4602353/domain_unstruct.vtk.gz')
+f = download('https://github.com/marcomusy/vedo/files/4602353/domain_unstruct.vtk.gz')
+ug = UnstructuredGrid(gunzip(f))
 
 # make up some custom vector field
-pts   = ug.points()
+pts   = ug.vertices
 x,y,z = pts.T
 windx = np.ones_like(x)*4
 windy = np.exp(-(x+18)**2/100) * np.sign(y)/(abs(y)+8)*20
@@ -17,6 +18,6 @@ ypr = np.linspace(-15,15, num=25)
 xpr = np.zeros_like(ypr)-40
 probes = np.c_[xpr, ypr]
 
-str_lns = StreamLines(ug, probes, max_propagation=80, lw=3)
+lines = ug.compute_streamlines(probes, max_propagation=80).c("red4")
 
-show(ars, str_lns, zoom=8, bg2='lb').close()
+show(ars, lines, zoom=8, bg2='lb').close()
