@@ -15,7 +15,7 @@ seeds = surf.clone().subsample(f2).ps(10).c("black")
 
 # assign to each tetrahedron the id of the closest seed point
 cids = []
-for p in tmesh.cell_centers:
+for p in tmesh.cell_centers().coordinates:
     cid = seeds.closest_point(p, return_point_id=True)
     cids.append(cid)
 tmesh.celldata["fragment"] = cids
