@@ -16,28 +16,34 @@ import logging
 import numpy as np
 from numpy import sin, cos, sqrt, exp, log, dot, cross  # just because handy
 
-from vtkmodules.vtkCommonCore import vtkVersion
+try:
+    from vtkmodules.vtkCommonCore import vtkVersion
+except ModuleNotFoundError:
+    print("Cannot find VTK installation. Please install it with:")
+    print("pip install vtk")
+    sys.exit(1)
 
 #################################################
 from vedo.version import _version as __version__
 
 from vedo.settings import Settings
-settings = Settings(level=0)
+settings = Settings()
 
 from vedo.colors import *
+from vedo.transformations import *
 from vedo.utils import *
-from vedo.base import *
+from vedo.core import *
 from vedo.shapes import *
 from vedo.file_io import *
-from vedo.ugrid import *
 from vedo.assembly import *
 from vedo.pointcloud import *
 from vedo.mesh import *
-from vedo.picture import *
+from vedo.image import *
 from vedo.volume import *
-from vedo.tetmesh import *
+from vedo.grids import *
 from vedo.addons import *
 from vedo.plotter import *
+from vedo.visual import *
 
 from vedo import applications
 from vedo import interactor_modes
@@ -90,7 +96,7 @@ last_figure = None
 ######################################################################### LOGGING
 class _LoggingCustomFormatter(logging.Formatter):
 
-    logformat = "[vedo.%(filename)s] %(levelname)s: %(message)s"
+    logformat = "[vedo.%(filename)s:%(lineno)d] %(levelname)s: %(message)s"
 
     white = "\x1b[1m"
     grey = "\x1b[2m\x1b[1m\x1b[38;20m"
@@ -115,18 +121,13 @@ class _LoggingCustomFormatter(logging.Formatter):
 logger = logging.getLogger("vedo")
 
 _chsh = logging.StreamHandler()
+if sys.stdout is None:
+    sys.stdout = open(os.devnull, "w")
+if sys.stderr is None:
+    sys.stderr = open(os.devnull, "w")
 _chsh.flush = sys.stdout.flush
 _chsh.setLevel(logging.DEBUG)
 _chsh.setFormatter(_LoggingCustomFormatter())
 logger.addHandler(_chsh)
 logger.setLevel(logging.INFO)
 
-################################################# silence annoying messages
-# import warnings
-# warnings.simplefilter(action="ignore", category=FutureWarning)
-# try:
-#     np.warnings.filterwarnings('ignore', category=np.VisibleDeprecationWarning)
-# except AttributeError:
-#     pass
-
-
