@@ -27,24 +27,27 @@ __all__ = [
     "VolumeAlgorithms",
 ]
 
-warnings = dict(
-    points_getter=(
-        "WARNING: points() is deprecated, use vertices instead. Change:\n"
-        "         mesh.points() -> mesh.vertices\n"
-        "         (silence this with vedo.core.warnings['points_getter']=False)"
-    ),
-    points_setter=(
-        "WARNING: points() is deprecated, use vertices instead. Change:\n"
-        "         mesh.points([[x,y,z], ...]) -> mesh.vertices = [[x,y,z], ...]\n"
-        "         (silence this with vedo.core.warnings['points_getter']=False)"
-    ),
-)
+
+###############################################################################
+# warnings = dict(
+#     func_name=(
+#         "WARNING: some message"
+#         " (silence this with vedo.core.warnings['func_name']=False)"
+#     ),
+# )
+# ### USAGE
+# def func_name(self):
+#     """Obsolete, use ... instead."""
+#         if warnings["func_name"]:
+#             colors.printc(warnings["func_name"], c="y")
+#             warnings["func_name"] = ""
+#         return
+
 
 ###############################################################################
 class DataArrayHelper:
     # Internal use only.
-    # Helper class to manage data associated to either
-    # points (or vertices) and cells (or faces).
+    # Helper class to manage data associated to either points (or vertices) and cells (or faces).
     def __init__(self, obj, association):
 
         self.obj = obj
@@ -584,60 +587,22 @@ class CommonAlgorithms:
         """Retrieve the number of cells."""
         return self.dataset.GetNumberOfCells()
 
-    def points(self, pts=None):
-        """Obsolete, use `self.vertices` or `self.coordinates` instead."""
-        if pts is None:  ### getter
-
-            if warnings["points_getter"]:
-                colors.printc(warnings["points_getter"], c="y")
-                warnings["points_getter"] = ""
-            return self.vertices
-
-        else:  ### setter
-
-            if warnings["points_setter"]:
-                colors.printc(warnings["points_setter"], c="y")
-                warnings["points_setter"] = ""
-
-            pts = np.asarray(pts, dtype=np.float32)
-
-            if pts.ndim == 1:
-                ### getter by point index ###################
-                indices = pts.astype(int)
-                vpts = self.dataset.GetPoints()
-                arr = utils.vtk2numpy(vpts.GetData())
-                return arr[indices]  ###########
-
-            ### setter ####################################
-            if pts.shape[1] == 2:
-                pts = np.c_[pts, np.zeros(pts.shape[0], dtype=np.float32)]
-            arr = utils.numpy2vtk(pts, dtype=np.float32)
-
-            vpts = self.dataset.GetPoints()
-            vpts.SetData(arr)
-            vpts.Modified()
-            # reset mesh to identity matrix position/rotation:
-            self.point_locator = None
-            self.cell_locator = None
-            self.line_locator = None
-            self.transform = LinearTransform()
-            return self
-
-    @property
-    def cell_centers(self):
+    def cell_centers(self, copy_arrays=False) -> "vedo.Points":
         """
-        Get the coordinates of the cell centers.
+        Get the coordinates of the cell centers as a `Points` object.
 
         Examples:
             - [delaunay2d.py](https://github.com/marcomusy/vedo/tree/master/examples/basic/delaunay2d.py)
-        
-        See also: `CellCenters()`.
         """
         vcen = vtki.new("CellCenters")
-        vcen.CopyArraysOff()
+        vcen.SetCopyArrays(copy_arrays)
+        vcen.SetVertexCells(copy_arrays)
         vcen.SetInputData(self.dataset)
         vcen.Update()
-        return utils.vtk2numpy(vcen.GetOutput().GetPoints().GetData())
+        vpts = vedo.Points(vcen.GetOutput())
+        if copy_arrays:
+            vpts.copy_properties_from(self)
+        return vpts
 
     @property
     def lines(self):
@@ -851,6 +816,16 @@ class CommonAlgorithms:
         self.line_locator = None
         self.transform = LinearTransform()
 
+    @property
+    def points(self):
+        """Return the vertices (points) coordinates. Same as `vertices`."""
+        return self.vertices
+
+    @points.setter
+    def points(self, pts):
+        """Set vertices (points) coordinates. Same as `vertices`."""
+        self.vertices = pts
+
     @property
     def coordinates(self):
         """Return the vertices (points) coordinates. Same as `vertices`."""
@@ -906,6 +881,40 @@ class CommonAlgorithms:
                 if i >= n:
                     break
         return conn
+    
+    def cell_edge_neighbors(self):
+        """
+        Get the cell neighbor indices of each cell.
+
+        Returns a python list of lists.
+        """
+
+        def face_to_edges(face):
+            edges = []
+            size = len(face)
+            for i in range(1, size + 1):
+                if i == size:
+                    edges.append([face[i - 1], face[0]])
+                else:
+                    edges.append([face[i - 1], face[i]])
+            return edges
+
+        pd = self.dataset
+        pd.BuildLinks()
+
+        neicells = []
+        for i, cell in enumerate(self.cells):
+            nn = []
+            for edge in face_to_edges(cell):
+                neighbors = vtki.vtkIdList()
+                pd.GetCellEdgeNeighbors(i, edge[0], edge[1], neighbors)
+                if neighbors.GetNumberOfIds() > 0:
+                    neighbor = neighbors.GetId(0)
+                    nn.append(neighbor)
+            neicells.append(nn)
+
+        return neicells
+
 
     def map_points_to_cells(self, arrays=(), move=False) -> Self:
         """
@@ -954,8 +963,8 @@ class CommonAlgorithms:
         ```python
         from vedo import *
         m1 = Mesh(dataurl+'bunny.obj')#.add_gaussian_noise(0.1)
-        pts = m1.vertices
-        ces = m1.cell_centers
+        pts = m1.coordinates
+        ces = m1.cell_centers().coordinates
         m1.pointdata["xvalues"] = np.power(pts[:,0], 3)
         m1.celldata["yvalues"]  = np.power(ces[:,1], 3)
         m2 = Mesh(dataurl+'bunny.obj')
@@ -1163,6 +1172,7 @@ class CommonAlgorithms:
         gra.ComputeVorticityOff()
         gra.ComputeGradientOn()
         gra.Update()
+        # self._update(gra.GetOutput(), reset_locators=False)
         if on.startswith("p"):
             gvecs = utils.vtk2numpy(gra.GetOutput().GetPointData().GetArray("Gradient"))
         else:
@@ -1209,6 +1219,7 @@ class CommonAlgorithms:
         div.SetDivergenceArrayName("Divergence")
         div.SetFasterApproximation(fast)
         div.Update()
+        # self._update(div.GetOutput(), reset_locators=False)
         if on.startswith("p"):
             dvecs = utils.vtk2numpy(div.GetOutput().GetPointData().GetArray("Divergence"))
         else:
@@ -1531,13 +1542,45 @@ class CommonAlgorithms:
 
     def smooth_data(self, 
             niter=10, relaxation_factor=0.1, strategy=0, mask=None,
+            mode="distance2",
             exclude=("Normals", "TextureCoordinates"),
         ) -> Self:
         """
         Smooth point attribute data using distance weighted Laplacian kernel.
-
         The effect is to blur regions of high variation and emphasize low variation regions.
 
+        A central concept of this method is the point smoothing stencil.
+        A smoothing stencil for a point p(i) is the list of points p(j) which connect to p(i) via an edge.
+        To smooth the attributes of point p(i), p(i)'s attribute data a(i) are iteratively averaged using
+        the distance weighted average of the attributes of a(j) (the weights w[j] sum to 1).
+        This averaging process is repeated until the maximum number of iterations is reached.
+
+        The relaxation factor (R) is also important as the smoothing process proceeds in an iterative fashion.
+        The a(i+1) attributes are determined from the a(i) attributes as follows:
+            a(i+1) = (1-R)*a(i) + R*sum(w(j)*a(j))
+    
+        Convergence occurs faster for larger relaxation factors.
+        Typically a small number of iterations is required for large relaxation factors,
+        and in cases where only points adjacent to the boundary are being smoothed, a single iteration with R=1 may be
+        adequate (i.e., just a distance weighted average is computed).
+
+        Warning:
+            Certain data attributes cannot be correctly interpolated. For example, surface normals are expected to be |n|=1;
+            after attribute smoothing this constraint is likely to be violated.
+            Other vectors and tensors may suffer from similar issues.
+            In such a situation, specify `exclude=...` which will not be smoothed (and simply passed through to the output).
+            Distance weighting function is based on averaging, 1/r, or 1/r**2 weights, where r is the distance
+            between the point to be smoothed and an edge connected neighbor (defined by the smoothing stencil).
+            The weights are normalized so that sum(w(i))==1. When smoothing based on averaging, the weights are simply 1/n,
+            where n is the number of connected points in the stencil.
+            The smoothing process reduces high frequency information in the data attributes.
+            With excessive smoothing (large numbers of iterations, and/or a large relaxation factor) important details may be lost,
+            and the attributes will move towards an "average" value.
+            While this filter will process any dataset type, if the input data is a 3D image volume, it's likely much faster to use
+            an image-based algorithm to perform data smoothing.
+            To determine boundary points in polygonal data, edges used by only one cell are considered boundary
+            (and hence the associated points defining the edge). 
+
         Arguments:
             niter : (int)
                 number of iterations
@@ -1550,6 +1593,11 @@ class CommonAlgorithms:
                     - 2: only point data connected to a boundary point are smoothed
             mask : (str, np.ndarray)
                 array to be used as a mask (ignore then the strategy keyword)
+            mode : (str)
+                smoothing mode, either "distance2", "distance" or "average"
+                    - distance**2 weighted (i.e., 1/r**2 interpolation weights)
+                    - distance weighted (i.e., 1/r) approach;
+                    - simple average of all connected points in the stencil
             exclude : (list)
                 list of arrays to be excluded from smoothing
         """
@@ -1565,7 +1613,15 @@ class CommonAlgorithms:
         for ex in exclude:
             saf.AddExcludedArray(ex)
 
-        saf.SetWeightsTypeToDistance2()
+        if mode == "distance":
+            saf.SetWeightsTypeToDistance()
+        elif mode == "distance2":
+            saf.SetWeightsTypeToDistance2()
+        elif mode == "average":
+            saf.SetWeightsTypeToAverage()
+        else:
+            vedo.logger.error(f"smooth_data(): unknown mode {mode}")
+            raise TypeError
 
         saf.SetSmoothingStrategy(strategy)
         if mask is not None:
@@ -1966,6 +2022,8 @@ class VolumeAlgorithms(CommonAlgorithms):
         Set `value` as single float or list of values to draw the isosurface(s).
         Use flying_edges for faster results (but sometimes can interfere with `smooth()`).
 
+        The isosurface values can be accessed with `mesh.metadata["isovalue"]`.
+
         Examples:
             - [isosurfaces1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/isosurfaces1.py)
 
@@ -1998,6 +2056,7 @@ class VolumeAlgorithms(CommonAlgorithms):
 
         out = vedo.mesh.Mesh(poly, c=None).phong()
         out.mapper.SetScalarRange(scrange[0], scrange[1])
+        out.metadata["isovalue"] = value
 
         out.pipeline = utils.OperationNode(
             "isosurface",
@@ -2007,7 +2066,9 @@ class VolumeAlgorithms(CommonAlgorithms):
         )
         return out
     
-    def isosurface_discrete(self, value=None, nsmooth=15) -> "vedo.mesh.Mesh":
+    def isosurface_discrete(
+            self, values, background_label=None, internal_boundaries=True, use_quads=False, nsmooth=0,
+        ) -> "vedo.mesh.Mesh":
         """
         Create boundary/isocontour surfaces from a label map (e.g., a segmented image) using a threaded,
         3D version of the multiple objects/labels Surface Nets algorithm.
@@ -2016,19 +2077,34 @@ class VolumeAlgorithms(CommonAlgorithms):
         labeled regions / objects.
         (Note that on output each region [corresponding to a different segmented object] will share
         points/edges on a common boundary, i.e., two neighboring objects will share the boundary that separates them).
+        
+        Besides output geometry defining the surface net, the filter outputs a two-component celldata array indicating
+        the labels on either side of the polygons composing the output Mesh. 
+        (This can be used for advanced operations like extracting shared/contacting boundaries between two objects.
+        The name of this celldata array is "BoundaryLabels").
+
+        The values can be accessed with `mesh.metadata["isovalue"]`.
 
         Arguments:
             value : (float, list)
                 single value or list of values to draw the isosurface(s).
+            background_label : (float)
+                this value specifies the label value to use when referencing the background
+                region outside of any of the specified regions.
+            boundaries : (bool, list)
+                if True, the output will only contain the boundary surface. Internal surfaces will be removed.
+                If a list of integers is provided, only the boundaries between the specified labels will be extracted.
+            use_quads : (bool)
+                if True, the output polygons will be quads. If False, the output polygons will be triangles.
             nsmooth : (int)
                 number of iterations of smoothing (0 means no smoothing).
 
         Examples:
             - [isosurfaces2.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/isosurfaces2.py)
         """
-        if not utils.is_sequence(value):
-            value = [value]
-        
+        logger = vtki.get_class("Logger")
+        logger.SetStderrVerbosity(logger.VERBOSITY_ERROR)
+
         snets = vtki.new("SurfaceNets3D")
         snets.SetInputData(self.dataset)
 
@@ -2041,20 +2117,44 @@ class VolumeAlgorithms(CommonAlgorithms):
         else:
             snets.SmoothingOff()
 
-        for i, val in enumerate(value):
+        if internal_boundaries is False:
+            snets.SetOutputStyleToBoundary()
+        elif internal_boundaries is True:
+            snets.SetOutputStyleToDefault()
+        elif utils.is_sequence(internal_boundaries):
+            snets.SetOutputStyleToSelected()
+            snets.InitializeSelectedLabelsList()
+            for val in internal_boundaries:
+                snets.AddSelectedLabel(val)
+        else:
+            vedo.logger.error("isosurface_discrete(): unknown boundaries option")
+
+        n = len(values)
+        snets.SetNumberOfContours(n)
+        snets.SetNumberOfLabels(n)
+
+        if background_label is not None:
+            snets.SetBackgroundLabel(background_label)
+
+        for i, val in enumerate(values):
             snets.SetValue(i, val)
-        snets.Update()
-        snets.SetOutputMeshTypeToTriangles()
-        snets.SetOutputStyleToBoundary()
+        
+        if use_quads:
+            snets.SetOutputMeshTypeToQuads()
+        else:
+            snets.SetOutputMeshTypeToTriangles()
         snets.Update()
 
         out = vedo.mesh.Mesh(snets.GetOutput())
+        out.metadata["isovalue"] = values
         out.pipeline = utils.OperationNode(
             "isosurface_discrete",
             parents=[self],
             comment=f"#pts {out.dataset.GetNumberOfPoints()}",
             c="#4cc9f0:#e9c46a",
         )
+
+        logger.SetStderrVerbosity(logger.VERBOSITY_INFO)
         return out
 
 
@@ -2063,7 +2163,7 @@ class VolumeAlgorithms(CommonAlgorithms):
         vmin=None,
         vmax=None,
         invert=False,
-        boundary=False,
+        boundary=True,
         array_name="input_scalars",
     ) -> "vedo.mesh.Mesh":
         """
@@ -2096,10 +2196,12 @@ class VolumeAlgorithms(CommonAlgorithms):
             srng[0] = vmin
         if vmax is not None:
             srng[1] = vmax
-        tol = 0.00001 * (srng[1] - srng[0])
-        srng[0] -= tol
-        srng[1] += tol
+        if not boundary:
+            tol = 0.00001 * (srng[1] - srng[0])
+            srng[0] -= tol
+            srng[1] += tol
         window.SetWindowRange(srng)
+        # print("legosurface window range:", srng)
 
         extract = vtki.new("ExtractGeometry")
         extract.SetInputData(self.dataset)
