@@ -387,7 +387,7 @@ class UnstructuredGrid(PointAlgorithms, MeshVisual):
                 name = self.dataset.GetCellData().GetScalars().GetName()
                 cdata = "<tr><td><b> cell data array </b></td><td>" + name + "</td></tr>"
 
-        pts = self.vertices
+        pts = self.coordinates
         cm = np.mean(pts, axis=0)
 
         all = [
@@ -685,13 +685,11 @@ class UnstructuredGrid(PointAlgorithms, MeshVisual):
 
     def find_cell(self, p: list) -> int:
         """Locate the cell that contains a point and return the cell ID."""
-        cell = vtki.vtkTetra()
-        cell_id = vtki.mutable(0)
-        tol2 = vtki.mutable(0)
-        sub_id = vtki.mutable(0)
-        pcoords = [0, 0, 0]
-        weights = [0, 0, 0]
-        cid = self.dataset.FindCell(p, cell, cell_id, tol2, sub_id, pcoords, weights)
+        if self.cell_locator is None:
+            self.cell_locator = vtki.new("CellLocator")
+            self.cell_locator.SetDataSet(self.dataset)
+            self.cell_locator.BuildLocator()
+        cid = self.cell_locator.FindCell(p)
         return cid
 
     def clean(self) -> Self:
@@ -1154,7 +1152,7 @@ class TetMesh(UnstructuredGrid):
                 name = self.dataset.GetCellData().GetScalars().GetName()
                 cdata = "<tr><td><b> cell data array </b></td><td>" + name + "</td></tr>"
 
-        pts = self.vertices
+        pts = self.coordinates
         cm = np.mean(pts, axis=0)
 
         allt = [
@@ -1257,7 +1255,7 @@ class TetMesh(UnstructuredGrid):
         )
         return self
 
-    def subdvide(self) -> Self:
+    def subdivide(self) -> Self:
         """
         Increase the number of tetrahedrons of a `TetMesh`.
         Subdivides each tetrahedron into twelve smaller tetras.
@@ -1266,7 +1264,7 @@ class TetMesh(UnstructuredGrid):
         sd.SetInputData(self.dataset)
         sd.Update()
         self._update(sd.GetOutput())
-        self.pipeline = utils.OperationNode("subdvide", c="#edabab", parents=[self])
+        self.pipeline = utils.OperationNode("subdivide", c="#edabab", parents=[self])
         return self
 
     def generate_random_points(self, n, min_radius=0) -> "vedo.Points":
@@ -1307,7 +1305,7 @@ class TetMesh(UnstructuredGrid):
         """
         cmesh = self.compute_cell_size()
         tets = cmesh.cells
-        verts = cmesh.vertices
+        verts = cmesh.coordinates
         cumul = np.cumsum(np.abs(cmesh.celldata["Volume"]))
 
         out_pts = []
@@ -1645,7 +1643,7 @@ class RectilinearGrid(PointAlgorithms, MeshVisual):
                 name = self.dataset.GetCellData().GetScalars().GetName()
                 cdata = "<tr><td><b> cell data array </b></td><td>" + name + "</td></tr>"
 
-        pts = self.vertices
+        pts = self.coordinates
         cm = np.mean(pts, axis=0)
 
         all = [
@@ -1919,7 +1917,7 @@ class StructuredGrid(PointAlgorithms, MeshVisual):
             x, y, z = np.meshgrid(cx, cy, cz)
 
             sgrid1 = StructuredGrid([x, y, z])
-            sgrid1.cmap("viridis", sgrid1.vertices[:, 0])
+            sgrid1.cmap("viridis", sgrid1.coordinates[:, 0])
             print(sgrid1)
 
             sgrid2 = sgrid1.clone().cut_with_plane(normal=(-1,1,1), origin=[14,34,44])
@@ -2146,7 +2144,7 @@ class StructuredGrid(PointAlgorithms, MeshVisual):
                 name = self.dataset.GetCellData().GetScalars().GetName()
                 cdata = "<tr><td><b> cell data array </b></td><td>" + name + "</td></tr>"
 
-        pts = self.vertices
+        pts = self.coordinates
         cm = np.mean(pts, axis=0)
 
         all = [
