@@ -21,13 +21,13 @@ Submodule to work with common format images.
 
 __all__ = [
     "Image",
-    "Picture",  # Deprecated, use Image instead
 ]
 
 
 #################################################
 def _get_img(obj: Union[np.ndarray, str], flip=False, translate=()) -> vtki.vtkImageData:
     # compute vtkImageData from numpy array or filename
+    img = None
 
     if isinstance(obj, str):
         if "https://" in obj:
@@ -991,10 +991,10 @@ class Image(vedo.visual.ImageVisual):
             parents = [self]
             if isinstance(source_pts, vedo.Points):
                 parents.append(source_pts)
-                source_pts = source_pts.vertices
+                source_pts = source_pts.coordinates
             if isinstance(target_pts, vedo.Points):
                 parents.append(target_pts)
-                target_pts = target_pts.vertices
+                target_pts = target_pts.coordinates
 
             ns = len(source_pts)
             nt = len(target_pts)
@@ -1167,6 +1167,7 @@ class Image(vedo.visual.ImageVisual):
         imap.SetLookupTable(lut)
         imap.SetInputData(img)
         imap.Update()
+
         self._update(imap.GetOutput())
         self.pipeline = utils.OperationNode(
             "cmap", comment=f'"{name}"', parents=[self], c="#f28482"
@@ -1482,11 +1483,3 @@ class Image(vedo.visual.ImageVisual):
             shape="cylinder",
         )
         return self
-
-#################################################
-class Picture(Image):
-    def __init__(self, obj=None, channels=3):
-        """Deprecated. Use `Image` instead."""
-        vedo.logger.warning("Picture() is deprecated, use Image() instead.")
-        super().__init__(obj=obj, channels=channels)
-
