@@ -775,7 +775,11 @@ def numpy2vtk(arr, dtype=None, deep=True, name=""):
     arr = np.ascontiguousarray(arr)
 
     if dtype == "id":
-        varr = numpy_to_vtkIdTypeArray(arr.astype(np.int64), deep=deep)
+        if vtki.vtkIdTypeArray().GetDataTypeSize() != 4:
+            ast = np.int64
+        else:
+            ast = np.int32
+        varr = numpy_to_vtkIdTypeArray(arr.astype(ast), deep=deep)
     elif dtype:
         varr = numpy_to_vtk(arr.astype(dtype), deep=deep)
     else:
@@ -899,7 +903,10 @@ def buildPolyData(vertices, faces=None, lines=None, strips=None, index_offset=0)
 
     vertices = make3d(vertices)
     source_points = vtki.vtkPoints()
-    source_points.SetData(numpy2vtk(vertices, dtype=np.float32))
+    if vedo.settings.force_single_precision_points:
+        source_points.SetData(numpy2vtk(vertices, dtype=np.float32))
+    else:
+        source_points.SetData(numpy2vtk(vertices))
     poly.SetPoints(source_points)
 
     if lines is not None:
@@ -1049,7 +1056,7 @@ def is_ragged(arr, deep=False) -> bool:
     """
     A ragged or inhomogeneous array in Python is an array
     with arrays of different lengths as its elements.
-    To check if an array is ragged,we iterate through the elements
+    To check if an array is ragged, we iterate through the elements
     and check if their lengths are the same.
 
     Example:
@@ -1459,7 +1466,7 @@ def get_uv(p, x, v):
         pic = Image(dataurl+"coloured_cube_faces.jpg")
         cb = Mesh(dataurl+"coloured_cube.obj").lighting("off").texture(pic)
 
-        cbpts = cb.vertices
+        cbpts = cb.points
         faces = cb.cells
         uv = cb.pointdata["Material"]
 
@@ -2088,7 +2095,7 @@ def camera_from_quaternion(pos, quaternion, distance=10000, ngl_correct=True) ->
     return camera
 
 
-def camera_from_neuroglancer(state, zoom=300) -> vtki.vtkCamera:
+def camera_from_neuroglancer(state, zoom) -> vtki.vtkCamera:
     """
     Define a `vtkCamera` from a neuroglancer state dictionary.
 
@@ -2097,7 +2104,6 @@ def camera_from_neuroglancer(state, zoom=300) -> vtki.vtkCamera:
             an neuroglancer state dictionary.
         zoom: (float)
             how much to multiply zoom by to get camera backoff distance
-            default = 300 > ngl_zoom = 1 > 300 nm backoff distance.
 
     Returns:
         `vtki.vtkCamera`, a vtk camera setup that matches this state.
@@ -2109,7 +2115,7 @@ def camera_from_neuroglancer(state, zoom=300) -> vtki.vtkCamera:
     return camera_from_quaternion(pos_nm, orient, pzoom * zoom, ngl_correct=True)
 
 
-def oriented_camera(center=(0, 0, 0), up_vector=(0, 1, 0), backoff_vector=(0, 0, 1), backoff=1.0) -> vtki.vtkCamera:
+def oriented_camera(center, up_vector, backoff_vector, backoff) -> vtki.vtkCamera:
     """
     Generate a `vtkCamera` pointed at a specific location,
     oriented with a given up direction, set to a backoff.
@@ -2457,14 +2463,14 @@ def vedo2trimesh(mesh):
     carr = mesh.celldata["CellIndividualColors"]
     ccols = carr
 
-    points = mesh.vertices
+    points = mesh.coordinates
     varr = mesh.pointdata["VertexColors"]
     vcols = varr
 
     if len(tris) == 0:
         tris = None
 
-    return Trimesh(vertices=points, faces=tris, face_colors=ccols, vertex_colors=vcols)
+    return Trimesh(vertices=points, faces=tris, face_colors=ccols, vertex_colors=vcols, process=False)
 
 
 def trimesh2vedo(inputobj):
