@@ -118,6 +118,7 @@ for name in [
     "vtkFloatArray",
     "vtkIdList",
     "vtkIntArray",
+    "vtkLogger",
     "vtkLookupTable",
     "vtkMath",
     "vtkPoints",
@@ -176,6 +177,7 @@ for name in [
     "vtkImplicitDataSet",
     "vtkImplicitSelectionLoop",
     "vtkImplicitWindowFunction",
+    # "vtkImplicitVolume",
     "vtkIterativeClosestPointTransform",
     "vtkLine",
     "vtkMultiBlockDataSet",
@@ -593,11 +595,11 @@ from vtkmodules.vtkInteractionWidgets import (
     vtkBalloonWidget,
     vtkBoxWidget,
     vtkContourWidget,
-    vtkPlaneWidget,
     vtkFocalPlanePointPlacer,
     vtkImplicitPlaneWidget,
     vtkOrientationMarkerWidget,
     vtkOrientedGlyphContourRepresentation,
+    vtkPlaneWidget,
     vtkPolygonalSurfacePointPlacer,
     vtkSliderWidget,
     vtkSphereWidget,
@@ -610,6 +612,7 @@ for name in [
     "vtkContourWidget",
     "vtkPlaneWidget",
     "vtkFocalPlanePointPlacer",
+    "vtkImageTracerWidget",
     "vtkImplicitPlaneWidget",
     "vtkOrientationMarkerWidget",
     "vtkOrientedGlyphContourRepresentation",
